@@ -1,7 +1,12 @@
 class Array:
-    def __init__(self, size=10, zero=None):
-        self.size = size
-        self.data = size * [zero]
+    def __init__(self, arg1, zero=None):
+        if type(arg1) is list:
+            self.size = len(arg1)
+            self.data = arg1[:]
+
+        elif type(arg1) is int:
+            self.size = arg1
+            self.data = self.size * [zero]
 
     def __str__(self):
         return str(self.data)
